@@ -48,7 +48,8 @@ void BweibScrmcmc(double survData[],
                   double samples_kappa3[],
                   double samples_theta[],
                   double samples_gamma[],
-                  double samples_misc[])
+                  double samples_misc[],
+                  double moveVec[])
 {
     GetRNGstate();
     
@@ -255,6 +256,9 @@ void BweibScrmcmc(double survData[],
         
         
         
+        moveVec[M] = (double) move;
+        
+        
         /* updating regression parameter: beta1 */
         
         if(move == 1)
